@@ -3,6 +3,7 @@
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.pyson import If, Equal, Eval, Not, In, Get
+from trytond.transaction import Transaction
 
 
 class OrderPoint(ModelSQL, ModelView):
@@ -79,10 +80,10 @@ class OrderPoint(ModelSQL, ModelView):
              'concurrent_internal_op': 'You can not define two order points '\
                  'on the same product with opposite locations.',})
 
-    def default_type(self, cursor, user, context=None):
+    def default_type(self):
         return "purchase"
 
-    def on_change_product(self, cursor, user, vals, context=None):
+    def on_change_product(self, vals):
         product_obj = self.pool.get('product.product')
         res = {
             'unit': False,
@@ -90,45 +91,46 @@ class OrderPoint(ModelSQL, ModelView):
             'unit_digits': 2,
         }
         if vals.get('product'):
-            product = product_obj.browse(cursor, user, vals['product'],
-                    context=context)
+            product = product_obj.browse(vals['product'])
             res['unit'] = product.default_uom.id
             res['unit.rec_name'] = product.default_uom.rec_name
             res['unit_digits'] = product.default_uom.digits
         return res
 
-    def get_unit(self, cursor, user, ids, name, context=None):
+    def get_unit(self, ids, name):
         res = {}
-        for order in self.browse(cursor, user, ids, context=context):
+        for order in self.browse(ids):
             res[order.id] = order.product.default_uom.id
         return res
 
-    def get_unit_digits(self, cursor, user, ids, name, context=None):
+    def get_unit_digits(self, ids, name):
         res = {}
-        for order in self.browse(cursor, user, ids, context=context):
+        for order in self.browse(ids):
             res[order.id] = order.product.default_uom.digits
         return res
 
-    def check_concurrent_internal(self, cursor, user, ids):
+    def check_concurrent_internal(self, ids):
         """
         Ensure that there is no 'concurrent' internal order
         points. I.E. no two order point with opposite location for the
         same product and same company.
         """
-        internal_ids = self.search(
-            cursor, user, [('id', 'in', ids), ('type', '=', 'internal')])
+        internal_ids = self.search([
+            ('id', 'in', ids), 
+            ('type', '=', 'internal'),
+            ])
         if not internal_ids:
             return True
 
         query = ['OR']
-        for op in self.browse(cursor, user, internal_ids):
+        for op in self.browse(internal_ids):
             arg = ['AND',
                    ('provisioning_location', '=', op.storage_location.id),
                    ('storage_location', '=', op.provisioning_location.id),
                    ('company', '=', op.company.id),
                    ('type', '=', 'internal')]
             query.append(arg)
-        ids = self.search(cursor, user, query)
+        ids = self.search(query)
         return not bool(ids)
 
     def _type2field(self, type=None):
@@ -139,14 +141,14 @@ class OrderPoint(ModelSQL, ModelView):
         else:
             return t2f[type]
 
-    def check_uniqueness(self, cursor, user, ids):
+    def check_uniqueness(self, ids):
         """
         Ensure uniqueness of order points. I.E that there is no several
         order point for the same location, the same product and the
         same company.
         """
         query = ['OR']
-        for op in self.browse(cursor, user, ids):
+        for op in self.browse(ids):
             field = self._type2field(op.type)
             arg = ['AND',
                    ('product', '=', op.product.id),
@@ -154,20 +156,20 @@ class OrderPoint(ModelSQL, ModelView):
                    ('id', '!=', op.id),
                    ('company', '=', op.company.id),]
             query.append(arg)
-        ids = self.search(cursor, user, query)
+        ids = self.search(query)
         return not bool(ids)
 
-    def get_rec_name(self, cursor, user, ids, name, context=None):
+    def get_rec_name(self, ids, name):
         if not ids:
             return {}
         if isinstance(ids, (int, long)):
             ids = [ids]
         res = {}
-        for op in self.browse(cursor, user, ids, context=context):
+        for op in self.browse(ids):
             res[op.id] = "%s@%s" % (op.product.name, op.location.name)
         return res
 
-    def search_rec_name(self, cursor, user, name, clause, context=None):
+    def search_rec_name(self, name, clause):
         res = []
         names = clause[2].split('@', 1)
         res.append(('product.template.name', clause[1], names[0]))
@@ -175,10 +177,10 @@ class OrderPoint(ModelSQL, ModelView):
             res.append(('location', clause[1], names[1]))
         return res
 
-    def get_location(self, cursor, user, ids, name, context=None):
+    def get_location(self, ids, name):
         location_obj = self.pool.get('stock.location')
         res = {}
-        for op in self.browse(cursor, user, ids, context=context):
+        for op in self.browse(ids):
             if op.type == 'purchase':
                 res[op.id] = op.warehouse_location.id
             elif op.type == 'internal':
@@ -187,20 +189,16 @@ class OrderPoint(ModelSQL, ModelView):
                 res[op.id] = False
         return res
 
-    def search_location(self, cursor, user, name, domain=None, context=None):
+    def search_location(self, name, domain=None):
         ids = []
         for type, field in self._type2field().iteritems():
             args = [('type', '=', type)]
             for _, operator, operand in domain:
                 args.append((field, operator, operand))
-            ids.extend(self.search(cursor, user, args, context=context))
+            ids.extend(self.search(args))
         return [('id', 'in', ids)]
 
-    def default_company(self, cursor, user, context=None):
-        if context is None:
-            context = {}
-        if context.get('company'):
-            return context['company']
-        return False
+    def default_company(self):
+        return Transaction().context.get('company') or False
 
 OrderPoint()
